@@ -8,31 +8,23 @@
 #' Unless `set_key_constraints` is `FALSE`, primary key constraints are set on all databases,
 #' and in addition foreign key constraints are set on MSSQL and Postgres databases.
 #'
-#' @details
-#' No tables will be overwritten; passing `overwrite = TRUE` to the function will give an error.
-#' Types are determined separately for each table, setting the `types` argument will
-#' also throw an error.
-#' The arguments are included in the signature to avoid passing them via the
-#' `...` ellipsis.
-#'
 #' @inheritParams dm_examine_constraints
 #'
 #' @param dest An object of class `"src"` or `"DBIConnection"`.
 #' @param dm A `dm` object.
-#' @param overwrite,types,indexes,unique_indexes Must remain `NULL`.
+#' @inheritParams rlang::args_dots_empty
 #' @param set_key_constraints If `TRUE` will mirror `dm` primary and foreign key constraints on a database
-#'   and create unique indexes.
+#'   and create indexes for foreign key constraints.
 #'   Set to `FALSE` if your data model currently does not satisfy primary or foreign key constraints.
-#' @param unique_table_names Deprecated.
 #' @param temporary If `TRUE`, only temporary tables will be created.
 #'   These tables will vanish when disconnecting from the database.
 #' @param schema Name of schema to copy the `dm` to.
-#' If `schema` is provided, an error will be thrown if `temporary = FALSE` or
-#' `table_names` is not `NULL`.
+#'   If `schema` is provided, an error will be thrown if `temporary = FALSE` or
+#'   `table_names` is not `NULL`.
 #'
-#' Not all DBMS are supported.
+#'   Not all DBMS are supported.
 #' @param table_names Desired names for the tables on `dest`; the names within the `dm` remain unchanged.
-#'   Can be `NULL`, a named character vector, a function or a one-sided formula.
+#'   Can be `NULL`, a named character vector, or a vector of [DBI::Id] objects.
 #'
 #'   If left `NULL` (default), the names will be determined automatically depending on the `temporary` argument:
 #'
@@ -62,21 +54,14 @@
 #'
 #'   Use qualified names corresponding to your database's syntax
 #'   to specify e.g. database and schema for your tables.
-#' @param copy_to By default, [dplyr::copy_to()] is called to upload the
-#'   individual tables to the target data source.
-#'   This argument allows overriding the standard behavior in cases
-#'   when the default does not work as expected, such as spatial data frames
-#'   or other tables with special data types.
-#'   If not `NULL`, this argument is processed with [rlang::as_function()].
-#' @param ... Passed on to [dplyr::copy_to()] or to the function specified
-#'   by the `copy_to` argument.
+#' @param unique_table_names,copy_to Must be `NULL`.
 #'
 #' @family DB interaction functions
 #'
 #' @return A `dm` object on the given `src` with the same table names
 #'   as the input `dm`.
 #'
-#' @examplesIf rlang::is_installed("RSQLite") && rlang::is_installed("nycflights13") && rlang::is_installed("dbplyr")
+#' @examplesIf rlang::is_installed(c("RSQLite", "nycflights13", "dbplyr"))
 #' con <- DBI::dbConnect(RSQLite::SQLite())
 #'
 #' # Copy to temporary tables, unique table names by default:
@@ -97,39 +82,25 @@
 #'
 #' DBI::dbDisconnect(con)
 #' @export
-copy_dm_to <- function(dest, dm, ...,
-                       types = NULL, overwrite = NULL,
-                       indexes = NULL, unique_indexes = NULL,
-                       set_key_constraints = TRUE, unique_table_names = NULL,
-                       table_names = NULL,
-                       temporary = TRUE,
-                       schema = NULL,
-                       progress = NA,
-                       copy_to = NULL) {
+copy_dm_to <- function(
+    dest,
+    dm,
+    ...,
+    set_key_constraints = TRUE,
+    table_names = NULL,
+    temporary = TRUE,
+    schema = NULL,
+    progress = NA,
+    unique_table_names = NULL,
+    copy_to = NULL) {
   # for the time being, we will be focusing on MSSQL
   # we want to
   #   1. change `dm_get_src_impl(dm)` to `dest`
   #   2. copy the tables to `dest`
   #   3. implement the key situation within our `dm` on the DB
 
-  if (!is_null(overwrite)) {
-    abort_no_overwrite()
-  }
-
-  if (!is_null(types)) {
-    abort_no_types()
-  }
-
-  if (!is_null(indexes)) {
-    abort_no_indexes()
-  }
-
-  if (!is_null(unique_indexes)) {
-    abort_no_unique_indexes()
-  }
-
   if (!is.null(unique_table_names)) {
-    deprecate_soft(
+    deprecate_warn(
       "0.1.4", "dm::copy_dm_to(unique_table_names = )",
       details = "Use `table_names = identity` to use unchanged names for temporary tables."
     )
@@ -139,6 +110,19 @@ copy_dm_to <- function(dest, dm, ...,
     }
   }
 
+  if (!is.null(copy_to)) {
+    deprecate_stop(
+      "1.0.0", "dm::copy_dm_to(copy_to = )",
+      details = "Use `dm_sql()` for more control over the schema creation process."
+    )
+  }
+
+  check_dots_empty()
+
+  check_not_zoomed(dm)
+
+  check_suggested("dbplyr", "copy_dm_to")
+
   dest <- src_from_src_or_con(dest)
   src_names <- src_tbls_impl(dm)
 
@@ -174,15 +158,13 @@ copy_dm_to <- function(dest, dm, ...,
     }
   } else {
     # FIXME: Other data sources than local and database possible
-    deprecate_soft(
+    deprecate_warn(
       "0.1.6", "dm::copy_dm_to(dest = 'must refer to a remote data source')",
       "dm::collect.dm()"
     )
     table_names_out <- set_names(src_names)
   }
 
-  check_not_zoomed(dm)
-
   # FIXME: if same_src(), can use compute() but need to set NOT NULL and other
   # constraints
 
@@ -191,6 +173,9 @@ copy_dm_to <- function(dest, dm, ...,
     return(dm)
   }
 
+  # Must be done here because table types may depend on string length, #2066
+  dm <- collect(dm, progress = progress)
+
   queries <- build_copy_queries(dest_con, dm, set_key_constraints, temporary, table_names_out)
 
   ticker_create <- new_ticker(
@@ -236,29 +221,21 @@ copy_dm_to <- function(dest, dm, ...,
     DBI::dbExecute(dest_con, .x, immediate = TRUE)
   }))
 
-  # build remote dm
-  remote_tables <-
-    queries$remote_name %>%
-    set_names(queries$name) %>%
-    map(tbl, src = dest_con)
   # remote dm is same as source dm with replaced data
   def <- dm_get_def(dm)
+
+  remote_tables <- map2(
+    table_names_out,
+    map(def$data, colnames),
+    ~ tbl(dest_con, ..1, vars = ..2)
+  )
+
   def$data <- unname(remote_tables[names(dm)])
-  remote_dm <- new_dm3(def)
+  remote_dm <- dm_from_def(def)
 
   invisible(debug_dm_validate(remote_dm))
 }
 
-get_db_table_names <- function(dm) {
-  if (!is_src_db(dm)) {
-    return(tibble(table_name = src_tbls_impl(dm), remote_name = src_tbls_impl(dm)))
-  }
-  tibble(
-    table_name = src_tbls_impl(dm),
-    remote_name = map_chr(dm_get_tables_impl(dm), dbplyr::remote_name)
-  )
-}
-
 check_naming <- function(table_names, dm_table_names) {
   if (!identical(sort(table_names), sort(dm_table_names))) {
     abort_copy_dm_to_table_names()
@@ -266,7 +243,7 @@ check_naming <- function(table_names, dm_table_names) {
 }
 
 db_append_table <- function(con, remote_table, table, progress, top_level_fun = "copy_dm_to", autoinc = logical(0)) {
-  table <- collect(table)
+  stopifnot(is.data.frame(table))
   if (nrow(table) == 0 || ncol(table) == 0) {
     return(invisible())
   }
@@ -278,7 +255,7 @@ db_append_table <- function(con, remote_table, table, progress, top_level_fun =
     chunk_size <- 1000L
     n_chunks <- ceiling(nrow(table) / chunk_size)
 
-    remote_table_id <- dbQuoteIdentifier(con, remote_table)
+    remote_table_id <- DBI::dbQuoteIdentifier(con, remote_table)
 
     ticker <- new_ticker(
       paste0("inserting into ", remote_table_id),
@@ -290,7 +267,7 @@ db_append_table <- function(con, remote_table, table, progress, top_level_fun =
     walk(seq_len(n_chunks), ticker(~ {
       end <- .x * chunk_size
       idx <- seq2(end - (chunk_size - 1), min(end, nrow(table)))
-      values <- map(table[idx, ], mssql_escape, con = con)
+      values <- map(table[idx, , drop = FALSE], mssql_escape, con = con)
       # Can't use dbAppendTable(): https://github.com/r-dbi/odbc/issues/480
       sql <- DBI::sqlAppendTable(con, remote_table_id, values, row.names = FALSE)
       if (length(autoinc) > 1L) abort("more than one autoincrement key in one table")
