@@ -14,8 +14,6 @@ test_that("API", {
 })
 
 test_that("`dm_set_colors()` works", {
-  skip_if_not_installed("nycflights13")
-
   expect_snapshot({
     dm_nycflights_small() %>%
       dm_set_colors(
@@ -38,7 +36,6 @@ test_that("`dm_set_colors()` works", {
 })
 
 test_that("`dm_set_colors()` errors if old syntax used", {
-  skip_if_not_installed("nycflights13")
   expect_dm_error(
     dm_set_colors(
       dm_nycflights_small(),
@@ -52,8 +49,6 @@ test_that("`dm_set_colors()` errors if old syntax used", {
 })
 
 test_that("`dm_set_colors()` errors with unnamed args", {
-  skip_if_not_installed("nycflights13")
-
   expect_dm_error(
     dm_set_colors(
       dm_nycflights_small(),
@@ -75,7 +70,6 @@ test_that("last", {
 
 test_that("bad color", {
   skip_if_not(getRversion() >= "3.5")
-  skip_if_not_installed("nycflights13")
 
   expect_dm_error(
     dm_set_colors(
@@ -87,8 +81,6 @@ test_that("bad color", {
 })
 
 test_that("getter", {
-  skip_if_not_installed("nycflights13")
-
   expect_equal(
     dm_get_colors(dm_nycflights13()),
     c(
@@ -119,11 +111,8 @@ test_that("helpers", {
 })
 
 test_that("output", {
-  skip_if_not_installed("DiagrammeRsvg")
-  skip_if_not_installed("nycflights13")
   skip_if_not_installed("testthat", "3.1.1")
 
-
   # 444: types
   expect_snapshot_diagram(
     dm_nycflights13() %>%
