@@ -16,18 +16,11 @@ test_that("output", {
     abort_last_col_missing()
     abort_no_cycles(create_graph_from_dm(dm_for_filter_w_cycle()))
     abort_tables_not_reachable_from_start()
-    abort_wrong_col_names("table_name", c("col_1", "col_2"), c("col_one", "col_2"))
-    abort_wrong_col_names("table_name", c("col_1", "col_2"), "col_one")
     abort_dupl_new_id_col_name("tibbletable")
     abort_no_overwrite()
-    abort_no_types()
-    abort_no_indexes()
-    abort_no_unique_indexes()
-    abort_key_constraints_need_db()
     abort_pk_not_defined()
     abort_fk_exists("child", c("child_1", "child_2"), "parent")
     abort_first_rm_fks("parent", c("child_1", "child_2"))
-    abort_no_src_or_con()
     abort_update_not_supported()
     abort_only_possible_wo_filters("find_wisdom")
     abort_tables_not_neighbors("subjects", "king")
@@ -42,9 +35,8 @@ test_that("output", {
     abort_con_only_for_dbi()
     abort_only_possible_wo_zoom("dm_zoom_to")
     abort_only_possible_w_zoom("dm_update_zoomed")
-    abort_learn_keys("some reason")
+    abort_learn_keys(error_cnd(message = "some reason"))
     abort_tbl_access("accessdenied")
-    abort_unnamed_table_list()
     abort_need_unique_names("clone")
     abort_fk_not_tracked("hook", "eye")
     abort_dm_invalid("it's ugly.")
@@ -54,7 +46,6 @@ test_that("output", {
     abort_cols_not_avail(c("pink5", "elephant"))
     abort_only_named_args("give_names", "frobnicability")
     abort_wrong_syntax_set_cols()
-    abort_temp_table_requested(c("i_am_temporary", "i_am_permanent"), "i_am_permanent")
     abort_pk_not_tracked("house", "house_number")
     abort_only_for_local_src(mtcars)
     abort_parameter_not_correct_class("number", correct_class = "numeric", class = "logical")
