@@ -1,29 +1,19 @@
 test_that("decompose_table() decomposes tables nicely on chosen source", {
-  # skip_if_src("maria")
-  skip_if_src_not(c("df", "duckdb"))
+  skip_if_src("maria")
 
   out <- decompose_table(data_ts(), aef_id, a, e, f)
-  # FIXME: Debug GHA fail
-  # expect_equivalent_tbl(
-  #   out$parent_table,
-  #   list_of_data_ts_parent_and_child()$parent_table,
-  #   # https://github.com/tidyverse/dbplyr/pull/496/files#r523986061
-  #   across(where(is.integer), as.numeric)
-  # )
-  # expect_equivalent_tbl(
-  #   out$child_table,
-  #   list_of_data_ts_parent_and_child()$child_table,
-  #   # https://github.com/tidyverse/dbplyr/pull/496/files#r523986061
-  #   across(where(is.integer), as.numeric)
-  # )
-  expect_snapshot(
-    {
-      out$parent_table
-      list_of_data_ts_parent_and_child()$parent_table
-      out$child_table
-      list_of_data_ts_parent_and_child()$child_table
-    },
-    variant = my_test_src_name
+
+  expect_equivalent_tbl(
+    out$parent_table,
+    list_of_data_ts_parent_and_child()$parent_table,
+    # https://github.com/tidyverse/dbplyr/pull/496/files#r523986061
+    across(where(is.integer), as.numeric)
+  )
+  expect_equivalent_tbl(
+    out$child_table,
+    list_of_data_ts_parent_and_child()$child_table,
+    # https://github.com/tidyverse/dbplyr/pull/496/files#r523986061
+    across(where(is.integer), as.numeric)
   )
 })
 
